==> Joomla_3.2.0_in_Japanese.zip: Joomla_3.2.0_in_Japanese/media/editors/tinymce/langs/it.js <==
tinymce.addI18n('it',{
"Cut": "Taglia",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Il tuo browser non supporta l'accesso diretto negli Appunti. Per favore usa i tasti di scelta rapida Ctrl+X\/C\/V.",
"Paste": "Incolla",
"Close": "Chiudi",
"Align right": "Allinea a Destra",
"New document": "Nuovo Documento",
"Numbered list": "Elenchi Numerati",
"Increase indent": "Aumenta Rientro",
"Formats": "Formattazioni",
"Select all": "Seleziona Tutto",
"Undo": "Annulla",
"Strikethrough": "Barrato",
"Bullet list": "Elenchi Puntati",
"Superscript": "Apice",
"Clear formatting": "Cancella Formattazione",
"Subscript": "Pedice",
"Redo": "Ripristina",
"Ok": "Ok",
"Bold": "Grassetto",
"Italic": "Corsivo",
"Align center": "Allinea al Centro",
"Decrease indent": "Riduci Rientro",
"Underline": "Sottolineato",
"Cancel": "Cancella",
"Justify": "Giustifica",
"Copy": "Copia",
"Align left": "Allinea a Sinistra",
"Visual aids": "Elementi Visivi",
"Lower Greek": "Minuscolo lettere greche",
"Square": "Quadrato",
"Default": "Predefinito",
"Lower Alpha": "Minuscolo alfanumerico",
"Circle": "Cerchio",
"Disc": "Disco",
"Upper Alpha": "Maiuscolo alfanumerico",
"Upper Roman": "Maiuscolo lettere romane",
"Lower Roman": "Minuscolo lettere romane",
"Name": "Nome",
"Anchor": "Fissa",
"You have unsaved changes are you sure you want to navigate away?": "Non hai salvato delle modifiche, sei sicuro di andartene?",
"Restore last draft": "Ripristina l'ultima bozza.",
"Special character": "Inserisci Carattere Speciale",
"Source code": "Codice Sorgente",
"Right to left": "Da Destra a Sinistra",
"Left to right": "Da Sinistra a Destra",
"Emoticons": "Faccine",
"Robots": "Robot",
"Document properties": "Propriet\u00e0 Documento",
"Title": "Titolo",
"Keywords": "Parola Chiave",
"Encoding": "Codifica",
"Description": "Descrizione",
"Author": "Autore",
"Fullscreen": "Schermo Intero",
"Horizontal line": "Linea Orizzontale",
"Horizontal space": "Spazio Orizzontale",
"Insert\/edit image": "Aggiungi\/Modifica Immagine",
"General": "Generale",
"Advanced": "Avanzato",
"Source": "URL",
"Border": "Bordo",
"Constrain proportions": "Mantieni Proporzioni",
"Vertical space": "Spazio Verticale",
"Image description": "Descrizione Immagine",
"Style": "Stile",
"Dimensions": "Dimensioni",
"Insert image": "Inserisci immagine",
"Insert date\/time": "Inserisci Data\/Ora",
"Remove link": "Rimuovi Link",
"Url": "Url",
"Text to display": "Testo da Visualizzare",
"Insert link": "Inserisci Link",
"New window": "Nuova Finestra",
"None": "No",
"Target": "Target",
"Insert\/edit link": "Inserisci\/Modifica Link",
"Insert\/edit video": "Inserisci\/Modifica Video",
"Poster": "Anteprima",
"Alternative source": "Alternativo",
"Paste your embed code below:": "Incolla qui il codice da incorporare:",
"Insert video": "Inserisci Video",
"Embed": "Incorporare",
"Nonbreaking space": "Spazio unificatore",
"Preview": "Anteprima",
"Print": "Stampa",
"Save": "Salva",
"Could not find the specified string.": "Impossibile trovare la parola specifica.",
"Replace": "Sostituisci",
"Next": "Successivo",
"Whole words": "Parole intere",
"Find and replace": "Trova e Sostituisci",
"Replace with": "Sostituisci con",
"Find": "Trova",
"Replace all": "Sostituisci tutto",
"Match case": "Maiuscole\/Minuscole ",
"Prev": "Precedente",
"Spellcheck": "Controllo ortografico",
"Finish": "Termina",
"Ignore all": "Ignora tutto",
"Ignore": "Ignora",
"Insert row before": "Inserisci una Riga prima",
"Rows": "Righe",
"Height": "Altezza",
"Paste row after": "Incolla una Riga dopo",
"Alignment": "Allineamento",
"Column group": "Gruppo di Colonne",
"Row": "Riga",
"Insert column before": "Inserisci una Colonna prima",
"Split cell": "Dividi Cella",
"Cell padding": "Padding della Cella",
"Cell spacing": "Spaziatura della Cella",
"Row type": "Tipo di Riga",
"Insert table": "Inserisci Tabella",
"Body": "Body",
"Caption": "Didascalia",
"Footer": "Footer",
"Delete row": "Cancella Riga",
"Paste row before": "Incolla una Riga prima",
"Scope": "Campo",
"Delete table": "Cancella Tabella",
"Header cell": "cella d'intestazione",
"Column": "Colonna",
"Cell": "Cella",
"Header": "Header",
"Cell type": "Tipo di Cella",
"Copy row": "Copia Riga",
"Row properties": "Propriet\u00e0 della Riga",
"Table properties": "Propriet\u00e0 della Tabella",
"Row group": "Gruppo di Righe",
"Right": "Destra",
"Insert column after": "Inserisci una Colonna dopo",
"Cols": "Colonne",
"Insert row after": "Inserisci una Riga dopo",
"Width": "Larghezza",
"Cell properties": "Propriet\u00e0 della Cella",
"Left": "Sinistra",
"Cut row": "Taglia Riga",
"Delete column": "Cancella Colonna",
"Center": "Centro",
"Merge cells": "Unisci Cella",
"Insert template": "Inserisci Template",
"Templates": "Template",
"Background color": "Colore Sfondo",
"Text color": "Colore Testo",
"Show blocks": "Mostra Blocchi",
"Show invisible characters": "Mostra Caratteri Invisibili",
"Words: {0}": "Parole: {0}",
"Insert": "Inserisci",
"File": "File",
"Edit": "Modifica",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Premi ALT-F9 per il men\u00f9. Premi ALT-F10 per la barra degli strumenti. Premi ALT-0 per l'aiuto.",
"Tools": "Strumenti",
"View": "Visualizza",
"Table": "Tabella",
"Format": "Formato",
"Inline": "Formato",
"Blocks": "Blocchi",
"Edit image": "Modifica Immagine",
"Font Family": "Famiglia Carattere",
"Font Sizes": "Grandezza Carattere",
"Paragraph": "Paragrafo",
"Address": "Indirizzo",
"Pre": "Preformattato",
"Code": "Codice",
"Headers": "Intestazioni",
"Header 1": "Intestazione 1",
"Header 2": "Intestazione 2",
"Header 3": "Intestazione 3",
"Header 4": "Intestazione 4",
"Header 5": "Intestazione 5",
"Header 6": "Intestazione 6",
"Insert Time": "Inserisci ora",
"Insert nonbreaking space": "Inserisci uno spazio",
"Toggle blockquote": "Testo quotato"
});

==> Joomla_3.4.2_in_Japanese.zip: Joomla_3.4.2_in_Japanese/media/editors/tinymce/langs/it.js <==
tinymce.addI18n('it',{
"Cut": "Taglia",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Il tuo browser non supporta l'accesso diretto negli Appunti. Per favore usa i tasti di scelta rapida Ctrl+X\/C\/V.",
"Paste": "Incolla",
"Close": "Chiudi",
"Align right": "Allinea a Destra",
"New document": "Nuovo Documento",
"Numbered list": "Elenchi Numerati",
"Increase indent": "Aumenta Rientro",
"Formats": "Formattazioni",
"Select all": "Seleziona Tutto",
"Undo": "Annulla",
"Strikethrough": "Barrato",
"Bullet list": "Elenchi Puntati",
"Superscript": "Apice",
"Clear formatting": "Cancella Formattazione",
"Subscript": "Pedice",
"Redo": "Ripristina",
"Ok": "Ok",
"Bold": "Grassetto",
"Italic": "Corsivo",
"Align center": "Allinea al Centro",
"Decrease indent": "Riduci Rientro",
"Underline": "Sottolineato",
"Cancel": "Cancella",
"Justify": "Giustifica",
"Copy": "Copia",
"Align left": "Allinea a Sinistra",
"Visual aids": "Elementi Visivi",
"Lower Greek": "Minuscolo lettere greche",
"Square": "Quadrato",
"Default": "Predefinito",
"Lower Alpha": "Minuscolo alfanumerico",
"Circle": "Cerchio",
"Disc": "Disco",
"Upper Alpha": "Maiuscolo alfanumerico",
"Upper Roman": "Maiuscolo lettere romane",
"Lower Roman": "Minuscolo lettere romane",
"Name": "Nome",
"Anchor": "Ancora",
"Anchors": "Ancora",
"You have unsaved changes are you sure you want to navigate away?": "Non hai salvato delle modifiche, sei sicuro di andartene?",
"Restore last draft": "Ripristina l'ultima bozza.",
"Special character": "Inserisci Carattere Speciale",
"Source code": "Codice Sorgente",
"Right to left": "Da Destra a Sinistra",
"Left to right": "Da Sinistra a Destra",
"Emoticons": "Faccine",
"Robots": "Robot",
"Document properties": "Propriet\u00e0 Documento",
"Title": "Titolo",
"Keywords": "Parola Chiave",
"Encoding": "Codifica",
"Description": "Descrizione",
"Author": "Autore",
"Fullscreen": "Schermo Intero",
"Horizontal line": "Linea Orizzontale",
"Horizontal space": "Spazio Orizzontale",
"Insert\/edit image": "Aggiungi\/Modifica Immagine",
"General": "Generale",
"Advanced": "Avanzato",
"Source": "URL",
"Border": "Bordo",
"Constrain proportions": "Mantieni Proporzioni",
"Vertical space": "Spazio Verticale",
"Image description": "Descrizione Immagine",
"Style": "Stile",
"Dimensions": "Dimensioni",
"Insert image": "Inserisci immagine",
"Insert date\/time": "Inserisci Data\/Ora",
"Remove link": "Rimuovi Link",
"Url": "Url",
"Text to display": "Testo da Visualizzare",
"Insert link": "Inserisci Link",
"New window": "Nuova Finestra",
"None": "No",
"Target": "Target",
"Insert\/edit link": "Inserisci\/Modifica Link",
"Insert\/edit video": "Inserisci\/Modifica Video",
"Poster": "Anteprima",
"Alternative source": "Alternativo",
"Paste your embed code below:": "Incolla qui il codice da incorporare:",
"Insert video": "Inserisci Video",
"Embed": "Incorporare",
"Nonbreaking space": "Spazio unificatore",
"Preview": "Anteprima",
"Print": "Stampa",
"Save": "Salva",
"Could not find the specified string.": "Impossibile trovare la parola specifica.",
"Replace": "Sostituisci",
"Next": "Successivo",
"Whole words": "Parole intere",
"Find and replace": "Trova e Sostituisci",
"Replace with": "Sostituisci con",
"Find": "Trova",
"Replace all": "Sostituisci tutto",
"Match case": "Maiuscole\/Minuscole ",
"Prev": "Precedente",
"Spellcheck": "Controllo ortografico",
"Finish": "Termina",
"Ignore all": "Ignora tutto",
"Ignore": "Ignora",
"Insert row before": "Inserisci una Riga prima",
"Rows": "Righe",
"Height": "Altezza",
"Paste row after": "Incolla una Riga dopo",
"Alignment": "Allineamento",
"Column group": "Gruppo di Colonne",
"Row": "Riga",
"Insert column before": "Inserisci una Colonna prima",
"Split cell": "Dividi Cella",
"Cell padding": "Padding della Cella",
"Cell spacing": "Spaziatura della Cella",
"Row type": "Tipo di Riga",
"Insert table": "Inserisci Tabella",
"Body": "Body",
"Caption": "Didascalia",
"Footer": "Footer",
"Delete row": "Cancella Riga",
"Paste row before": "Incolla una Riga prima",
"Scope": "Campo",
"Delete table": "Cancella Tabella",
"Header cell": "cella d'intestazione",
"Column": "Colonna",
"Cell": "Cella",
"Header": "Header",
"Cell type": "Tipo di Cella",
"Copy row": "Copia Riga",
"Row properties": "Propriet\u00e0 della Riga",
"Table properties": "Propriet\u00e0 della Tabella",
"Row group": "Gruppo di Righe",
"Right": "Destra",
"Insert column after": "Inserisci una Colonna dopo",
"Cols": "Colonne",
"Insert row after": "Inserisci una Riga dopo",
"Width": "Larghezza",
"Cell properties": "Propriet\u00e0 della Cella",
"Left": "Sinistra",
"Cut row": "Taglia Riga",
"Delete column": "Cancella Colonna",
"Center": "Centro",
"Merge cells": "Unisci Cella",
"Insert template": "Inserisci Template",
"Templates": "Template",
"Background color": "Colore Sfondo",
"Text color": "Colore Testo",
"Show blocks": "Mostra Blocchi",
"Show invisible characters": "Mostra Caratteri Invisibili",
"Words: {0}": "Parole: {0}",
"Insert": "Inserisci",
"File": "File",
"Edit": "Modifica",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Premi ALT-F9 per il men\u00f9. Premi ALT-F10 per la barra degli strumenti. Premi ALT-0 per l'aiuto.",
"Tools": "Strumenti",
"View": "Visualizza",
"Table": "Tabella",
"Format": "Formato",
"Inline": "Formato",
"Blocks": "Blocchi",
"Edit image": "Modifica Immagine",
"Font Family": "Famiglia Carattere",
"Font Sizes": "Grandezza Carattere",
"Paragraph": "Paragrafo",
"Address": "Indirizzo",
"Pre": "Preformattato",
"Code": "Codice",
"H Align": "Allineamento orizzontale",
"V Align": "Allineamento verticale",
"Top": "Sopra",
"Middle": "Al centro",
"Bottom": "Sotto",
"Headers": "Intestazioni",
"Header 1": "Intestazione 1",
"Header 2": "Intestazione 2",
"Header 3": "Intestazione 3",
"Header 4": "Intestazione 4",
"Header 5": "Intestazione 5",
"Header 6": "Intestazione 6",
"Headings": "Intestazioni",
"Heading 1": "Intestazione 1",
"Heading 2": "Intestazione 2",
"Heading 3": "Intestazione 3",
"Heading 4": "Intestazione 4",
"Heading 5": "Intestazione 5",
"Heading 6": "Intestazione 6",
"Add to Dictionary": "Aggiungi al dizionario",
"Insert Time": "Inserisci ora",
"Insert nonbreaking space": "Inserisci uno spazio",
"Toggle blockquote": "Testo quotato",
"Border color": "Colore bordo",
"Color": "Colore",
"Custom...": "Personalizza...",
"Custom color": "Personalizz colore",
"No color": "Nessun colore",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "L'URL inserito sembra essere un collegamento esterno. Vuoi aggiungere il prefisso necessario http:\/\/?",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "L'URL inserito sembra essere un indirizzo email. Vuoi aggiungere il prefisso necessario mailto:?"
});
